pub fn unicode_convert(string: &str, style: &str) -> Option<String>Expand description
Convert a string’s characters to the styled Unicode equivalent for the given mathvariant.
Port of Perl’s unicode_convert($string, $style).
Returns None if any character in the string has no mapping (all-or-nothing semantics).